@@ -5,12 +5,13 @@
 
 package org.wildfly.clustering.singleton.server;
 
-import org.wildfly.clustering.dispatcher.CommandDispatcher;
+import org.wildfly.clustering.server.GroupMember;
+import org.wildfly.clustering.server.dispatcher.CommandDispatcher;
 import org.wildfly.clustering.service.ServiceNameProvider;
 
 /**
  * @author Paul Ferraro
  */
 public interface PrimaryProxyContext<T> extends ServiceNameProvider {
-    CommandDispatcher<LegacySingletonContext<T>> getCommandDispatcher();
+    CommandDispatcher<GroupMember, LegacySingletonContext<T>> getCommandDispatcher();
 }
